@@ -1,6 +1,6 @@
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __author__ = 'Xinqi Yang'
 
-from messagehub.core.messagehub import (api, bar, flash, wallet, transaction, defi)
+from messagehub.core.messagehub import (api, bar, flash, wallet, transaction, defi, info)
 
 from messagehub.util.formula import (EMA, MA, SMA, ATR, HHV, LLV, SUM, ABS, MAX, MIN, IF, REF, STD, MACD, KDJ, OSC, BBI, BBIBOLL, PBX, BOLL, ROC, MTM, MFI, SKDJ, WR, BIAS, RSI, ADTM, DDI)
